# instantiate.py -- test LRU cache instantiation

# Copyright 2004 Evan Prodromou <evan@bad.dynu.ca>
# Licensed under the Academic Free License 2.1

# arch-tag: LRU cache instantiation tests

"""Test cases for LRUCache instantiation"""

import unittest
import lrucache

class DefaultCase(unittest.TestCase):
    """Default (no-arg) instantiation"""
    
    def setUp(self):
        """Create no-arg cache"""
        self.cache = lrucache.LRUCache()
	
    def testinit(self):
        """No-arg cache creation returns a value"""
        self.assert_(self.cache is not None)

    def testsize(self):
        """No-arg cache has default size"""        
        self.assertEqual(self.cache.size, lrucache.DEFAULT_SIZE)
	
class NormalArgumentCase(unittest.TestCase):
    """Integer arg instantiation"""
    
    size = 10
    
    def setUp(self):
        """Instantiate with integer arg"""        
        self.cache = lrucache.LRUCache(self.size)

    def testinit(self):
        """Integer arg instantiation returns a value"""
        self.assert_(self.cache is not None)

    def testsize(self):
        """Integer arg cache has provided size"""        
        self.assertEqual(self.cache.size, self.size)

class ZeroArgumentCase(unittest.TestCase):
    """Integer arg instantiation with zero"""
    
    def testargcheck(self):
        """Instantiation with zero returns ValueError"""        
        self.assertRaises(ValueError, lrucache.LRUCache, 0)

class NegativeArgumentCase(unittest.TestCase):
    """Negative arg instantiation"""
    
    def testargcheck(self):
        """Instantiation with negative number returns ValueError"""
        self.assertRaises(ValueError, lrucache.LRUCache, -1)

class StringArgumentCase(unittest.TestCase):
    """String arg instantiation"""
    
    def testargcheck(self):
        """Instantiation with string raises TypeError"""
        self.assertRaises(TypeError, lrucache.LRUCache, "not a number")

class FloatArgumentCase(unittest.TestCase):
    """Float arg instantiation"""
    
    def testargcheck(self):
        """Instantiation with float raises TypeError"""        
        self.assertRaises(TypeError, lrucache.LRUCache, 3.14159)
	
if __name__ == "__main__":
    unittest.main()
